/* xattr-at-flagtab.h --
 * Copyright Red Hat Inc.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Attila Lakatos <alakatos@redhat.com>
 *      Location: include/uapi/linux/fcntl.h fs/xattr.c
 */

// Handled in the code _S(00,		"LOOKUP_FOLLOW" )
_S(0x100,		"AT_SYMLINK_NOFOLLOW" )
_S(0x800,		"AT_NO_AUTOMOUNT" )
_S(0x1000,		"AT_EMPTY_PATH" )
_S(0x8000,		"AT_RECURSIVE" )
